
import { SCREEN_HEIGHT, SCREEN_WIDTH } from './Constants'
import Orientation from 'react-native-orientation';
import { View, Text, StyleSheet, ScrollView, TouchableOpacity, StatusBar } from 'react-native';
import React, { Component } from 'react';
import { Image } from 'react-native';
import Colors from './Colors'
import { RNCamera } from 'react-native-camera';
import Icon from 'react-native-vector-icons/FontAwesome';
import moment from 'react-moment'
import Geolocation from '@react-native-community/geolocation';


const crossMark = require('./Image/crossMark.png')
const tickMark = require('./Image/tickMark.png')

export default class Camera extends Component {
    constructor(props) {
        super(props);
        this.state = ({
            isPressed: false,
            torchon: '',
            isDisplayPreview: false,
            localPath: '',
            flashState: true,
            dateAndTime: '',
            currentLongitude: 'unknown',//Initial Longitude
            currentLatitude: 'unknown',//Initial Latitude
        })
    }

    takePicture = async function (camera) {
        const options = { quality: 1, base64: true };
        const data = await camera.takePictureAsync(options);
        //  eslint-disable-next-line
        this.setState({ localPath: data.uri })

        console.log(data.uri);
        this.props.screenProps.setIsDisplayPreview(true)
        console.log(this.state.localPath)
        this.props.screenProps.setLocalPath(data.uri)



        const date = new Date().getDate();
        const month = new Date().getMonth() + 1;
        const year = new Date().getFullYear();


        const hour = new Date().getHours();
        const minute = new Date().getMinutes();
        const seconds = new Date().getSeconds();
        //Alert.alert(date + '-' + month + '-' + year);
        // You can turn it in to your desired format
        this.setState({ dateAndTime: date + '-' + month + '-' + year + "  " + hour + '-' + minute + '-' + seconds })//format: dd-mm-yyyy;

    }

    toggleTorch() {
        if (this.state.flashState == true) {
            console.log('AUTO')
            this.setState({ flashState: false })
        } else {
            this.setState({ flashState: true })
            console.log('ON')


        }
    }
    render() {
        return (
            <View style={styles.container}>
                <StatusBar
                    hidden={true}
                />
                <RNCamera
                    style={styles.preview}
                    type={RNCamera.Constants.Type.back}
                    flashMode={this.state.flashState
                        ? RNCamera.Constants.FlashMode.on
                        : RNCamera.Constants.FlashMode.auto}
                    androidCameraPermissionOptions={{
                        title: 'Permission to use camera',
                        message: 'We need your permission to use your camera',
                        buttonPositive: 'Ok',
                        buttonNegative: 'Cancel',
                    }}
                    androidRecordAudioPermissionOptions={{
                        title: 'Permission to use audio recording',
                        message: 'We need your permission to use your audio',
                        buttonPositive: 'Ok',
                        buttonNegative: 'Cancel',
                    }}
                    // pausePreview={true}
                    // pauseAfterCapture={true}
                    autoFocus={true}
                    resumePreview={true}


                >

                    {({ camera, status, recordAudioPermissionStatus }) => {
                        // if (status !== 'READY') return <PendingView />;
                        return (
                            // <View style={styles.cameraIconView}>
                            // <TouchableOpacity onPress={() => [this.takePicture(camera)]} style={styles.capture}>
                            //     {/* <Text style={{ fontSize: 14 }}> SNAP </Text> */}
                            //     <Icon
                            //         name="camera"
                            //     />
                            // </TouchableOpacity>
                            // <TouchableOpacity onPress={() => [this.toggleTorch()]} style={styles.flash}>
                            //     {/* <Text style={{ fontSize: 14 }}> SNAP </Text> */}
                            //     <Icon
                            //         name="flash"
                            //     />
                            // </TouchableOpacity>

                            // </View>
                            <View style={{ flex: 1, position: 'absolute', width: SCREEN_WIDTH, height: SCREEN_HEIGHT }}>
                                <Image
                                    source={crossMark}
                                    style={{ width: 50, height: 50, position: 'absolute', left: 1, marginLeft: 15, marginTop: 10 }}
                                />
                                <Image
                                    source={crossMark}
                                    style={{ width: 50, height: 50, position: 'absolute', left: 1, bottom: 1, marginLeft: 15, marginBottom: 10 }}
                                />
                                <Image
                                    source={crossMark}
                                    style={{ width: 50, height: 50, position: 'absolute', right: 1, bottom: 1, marginRight: 15, marginBottom: 10 }}
                                />
                                <Image
                                    source={crossMark}
                                    style={{ width: 50, height: 50, position: 'absolute', right: 1, marginRight: 15, marginTop: 10 }}
                                />

                                <View style={{ flex: 1 }}>
                                    <View style={{ flex: 0.5, justifyContent: 'flex-end' }}>
                                        <TouchableOpacity onPress={() => [this.takePicture(camera)]} style={styles.capture}>
                                            {/* <Text style={{ fontSize: 14 }}> SNAP </Text> */}
                                            <Icon
                                                name="camera"
                                            />
                                        </TouchableOpacity>
                                    </View>
                                    <View style={{ flex: 0.5 }}>
                                        <TouchableOpacity onPress={() => [this.toggleTorch()]} style={styles.flash}>
                                            {/* <Text style={{ fontSize: 14 }}> SNAP </Text> */}
                                            <Icon
                                                name="flash"
                                            />
                                        </TouchableOpacity>
                                    </View>
                                </View>

                            </View>
                        );

                    }}

                </RNCamera>

            </View>
        );
    }
}
const styles = StyleSheet.create({
    main: {
        flex: 1,
        flexDirection: 'row'
    },
    productImageView: {
        flex: 0.475,
    },
    blankView: {
        flex: 0.05,
    },
    productInfoView: {
        flex: 0.475,
        marginRight: 16,
        width: SCREEN_WIDTH,
        height: SCREEN_HEIGHT
    },
    headerView: {
        backgroundColor: '#C6AFFF',
        height: 40,
        justifyContent: 'center'
    },
    headerText: {
        marginLeft: 16,
        fontSize: 20,
        fontFamily: 'Muli-Black'
    },
    productImageStyle: {
        marginTop: 8,
        marginLeft: 16,
        marginBottom: 40,
        height: SCREEN_HEIGHT - 70
    },
    backButtonImageStyle: {
        marginLeft: 32,
        height: 24,
        width: 24,
        backgroundColor: 'red'
    },
    subHeaderText: {
        fontFamily: 'Mulli-Regular',
        fontSize: 16,
        marginLeft: 16
    },
    instructionText: {
        fontFamily: 'Mulli-Regular',
        fontSize: 16,
        marginLeft: 16,
        marginBottom: 20
    },
    captureImageButtonView: {
        height: 48,
        borderRadius: 4,
        backgroundColor: Colors.digitYellow,
        marginTop: 2,
        flexDirection: 'row',
        justifyContent: 'center',
    },
    captureImageButtonText: {
        fontSize: 16,
        fontFamily: 'Muli-Black',
        alignSelf: 'center'
    },
    container: {
        flex: 1,
        // flexDirection: 'row',
        // backgroundColor: 'black',
    },
    preview: {
        flex: 1,
        justifyContent: 'flex-end',
        alignItems: 'center',
    },
    capture: {
        flex: 0,
        backgroundColor: '#fff',
        borderRadius: 5,
        padding: 15,
        paddingHorizontal: 20,
        alignSelf: 'flex-end',
        margin: 20,
        position: 'absolute'
    },
    flash: {
        flex: 0,
        backgroundColor: '#fff',
        borderRadius: 5,
        padding: 15,
        paddingHorizontal: 20,
        alignSelf: 'flex-end',
        margin: 20,
        position: 'absolute'
    },
    previewImageStyle: {
        width: SCREEN_WIDTH,
        height: SCREEN_HEIGHT
    },
    dateAndTimeText: {
        position: 'absolute',
        fontSize: 20,
        color: Colors.digitYellow,
        left: 1,
        bottom: 1
    },
    previewImageIconMainView: {
        flex: 0.05,
        backgroundColor: 'black'
    },
    tickMarkImageView: {
        flex: 0.6,
        justifyContent: 'flex-end'
    },
    tickMarkImageStyle: {
        width: 30,
        height: 30,
        backgroundColor: 'white',
        alignContent: 'flex-end',
        marginBottom: 20
    },
    crossImageView: {
        flex: 0.4,
        justifyContent: 'flex-end',
        marginBottom: 20
    },
    crossImageStyle: {
        width: 30,
        height: 30,
        backgroundColor: 'white',
        alignContent: 'flex-end'
    },
    cameraIconView: {
        flexDirection: 'row',
        justifyContent: 'center',
        width: SCREEN_WIDTH,
        position: 'absolute'
    },
    infoScrollView: {
        marginTop: 40,
        height: SCREEN_HEIGHT - 200
    },
    subHeaderTextView: {
        height: 40,
        marginTop: 8
    },
    backButtonImageView: {
        backgroundColor: '#C6AFFF',
        height: 40,
        justifyContent: 'center',
        marginLeft: 16
    },
    latLongText: {
        position: 'absolute',
        fontSize: 20,
        color: Colors.digitYellow,
        left: 1,
    },
    digitEdgeText: {
        position: 'absolute',
        fontSize: 20,
        color: Colors.digitYellow,
        right: 1,
    }


});


