
import { SCREEN_HEIGHT, SCREEN_WIDTH } from './Constants'
import Orientation from 'react-native-orientation';
import { View, Text, StyleSheet, ScrollView, TouchableOpacity, StatusBar } from 'react-native';
import React, { Component } from 'react';
import { Image } from 'react-native';
import Colors from './Colors'
import { RNCamera } from 'react-native-camera';
import Icon from 'react-native-vector-icons/FontAwesome';
import moment from 'react-moment'
import Geolocation from '@react-native-community/geolocation';
import Camera from 'react-native-digitcameraf/src/common/Camera';


const crossMark = require('./Image/crossMark.png')
const tickMark = require('./Image/tickMark.png')

export default class previewImage extends Component {
    constructor(props) {
        super(props);
        this.state = ({
            isPressed: false,
            torchon: '',
            isDisplayPreview: false,
            localPath: '',
            flashState: true,
            dateAndTime: '',
            currentLongitude: 'unknown',//Initial Longitude
            currentLatitude: 'unknown',//Initial Latitude
        })
    }
    render() {
        return (
            <View style={{ flex: 1, flexDirection: 'row' }}>
                <View style={{ flex: 0.05, backgroundColor: 'black' }}></View>
                <View style={{ flex: 0.9, backgroundColor: 'black' }}>
                    <Image
                        source={{ uri: this.state.localPath }}
                        style={styles.previewImageStyle}
                    />
                    <Text style={styles.latLongText}>lat: {this.state.currentLatitude} long:{this.state.currentLongitude}</Text>

                    <Text style={styles.dateAndTimeText}>{this.state.dateAndTime}</Text>
                    <Text style={styles.digitEdgeText}>DigitEdge</Text>


                </View>
                <View style={styles.previewImageIconMainView}>
                    <View style={styles.tickMarkImageView}>
                        <TouchableOpacity>
                            <Image
                                source={tickMark}
                                style={styles.tickMarkImageStyle}
                            />
                        </TouchableOpacity>

                    </View>


                    <View style={styles.crossImageView}>
                        <TouchableOpacity onPress={() => this.setState({ isDisplayPreview: false })}>
                            <Image
                                source={crossMark}
                                style={styles.crossImageStyle}
                            />
                        </TouchableOpacity>

                    </View>
                </View>

            </View>

        )
    }
}
const styles = StyleSheet.create({
    main: {
        flex: 1,
        flexDirection: 'row'
    },
    productImageView: {
        flex: 0.475,
    },
    blankView: {
        flex: 0.05,
    },
    productInfoView: {
        flex: 0.475,
        marginRight: 16,
        width: SCREEN_WIDTH,
        height: SCREEN_HEIGHT
    },
    headerView: {
        backgroundColor: '#C6AFFF',
        height: 40,
        justifyContent: 'center'
    },
    headerText: {
        marginLeft: 16,
        fontSize: 20,
        fontFamily: 'Muli-Black'
    },
    productImageStyle: {
        marginTop: 8,
        marginLeft: 16,
        marginBottom: 40,
        height: SCREEN_HEIGHT - 70
    },
    backButtonImageStyle: {
        marginLeft: 32,
        height: 24,
        width: 24,
        backgroundColor: 'red'
    },
    subHeaderText: {
        fontFamily: 'Mulli-Regular',
        fontSize: 16,
        marginLeft: 16
    },
    instructionText: {
        fontFamily: 'Mulli-Regular',
        fontSize: 16,
        marginLeft: 16,
        marginBottom: 20
    },
    captureImageButtonView: {
        height: 48,
        borderRadius: 4,
        backgroundColor: Colors.digitYellow,
        marginTop: 2,
        flexDirection: 'row',
        justifyContent: 'center',
    },
    captureImageButtonText: {
        fontSize: 16,
        fontFamily: 'Muli-Black',
        alignSelf: 'center'
    },
    container: {
        flex: 1,
        // flexDirection: 'row',
        // backgroundColor: 'black',
    },
    preview: {
        flex: 1,
        justifyContent: 'flex-end',
        alignItems: 'center',
    },
    capture: {
        flex: 0,
        backgroundColor: '#fff',
        borderRadius: 5,
        padding: 15,
        paddingHorizontal: 20,
        alignSelf: 'flex-end',
        margin: 20,
        position: 'absolute'
    },
    flash: {
        flex: 0,
        backgroundColor: '#fff',
        borderRadius: 5,
        padding: 15,
        paddingHorizontal: 20,
        alignSelf: 'flex-end',
        margin: 20,
        position: 'absolute'
    },
    previewImageStyle: {
        width: SCREEN_WIDTH,
        height: SCREEN_HEIGHT
    },
    dateAndTimeText: {
        position: 'absolute',
        fontSize: 20,
        color: Colors.digitYellow,
        left: 1,
        bottom: 1
    },
    previewImageIconMainView: {
        flex: 0.05,
        backgroundColor: 'black'
    },
    tickMarkImageView: {
        flex: 0.6,
        justifyContent: 'flex-end'
    },
    tickMarkImageStyle: {
        width: 30,
        height: 30,
        backgroundColor: 'white',
        alignContent: 'flex-end',
        marginBottom: 20
    },
    crossImageView: {
        flex: 0.4,
        justifyContent: 'flex-end',
        marginBottom: 20
    },
    crossImageStyle: {
        width: 30,
        height: 30,
        backgroundColor: 'white',
        alignContent: 'flex-end'
    },
    cameraIconView: {
        flexDirection: 'row',
        justifyContent: 'center',
        width: SCREEN_WIDTH,
        position: 'absolute'
    },
    infoScrollView: {
        marginTop: 40,
        height: SCREEN_HEIGHT - 200
    },
    subHeaderTextView: {
        height: 40,
        marginTop: 8
    },
    backButtonImageView: {
        backgroundColor: '#C6AFFF',
        height: 40,
        justifyContent: 'center',
        marginLeft: 16
    },
    latLongText: {
        position: 'absolute',
        fontSize: 20,
        color: Colors.digitYellow,
        left: 1,
    },
    digitEdgeText: {
        position: 'absolute',
        fontSize: 20,
        color: Colors.digitYellow,
        right: 1,
    }


});
